@@ -50,10 +50,13 @@ foreach my $controller (keys %controllers)
 my $output = "";
 
 # Alleen de 'permanente' ssid's krijgen een eigen lijntje op de grafiek
-my @permanent = ('UvT-Welcome','eduroam', 'Noc-Test', 'TN-Wireless', 'Faculty Club');
+my @permanent = ('eduroam', 'Noc-Test', 'TN-Wireless', 'Faculty Club');
 foreach my $permanent_ssid (@permanent)
 {
-    $output .= "$permanent_ssid:$totalAssociationsPerWLAN{$permanent_ssid} ";
+    my $perm_cacti_ssid = $permanent_ssid;
+    $perm_cacti_ssid =~ s/ /_/g;
+
+    $output .= "$perm_cacti_ssid:$totalAssociationsPerWLAN{$permanent_ssid} ";
     delete($totalAssociationsPerWLAN{$permanent_ssid});
 }
 
